<TS version="2.1" language="fo">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">Høgraklikk fyri at broyta adressu ella spjaldur</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">Stovna adressu</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">Strika valdu adressuna av listanum</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">Leita eftir adressu ella spjaldri</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;Avrita addressu</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">Avrita &amp;Spjaldur</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Broyt</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">Villa við goyming av adressuskrá til %1. Vinaliga royn aftur.</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Spjaldur</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Adressa</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(einki spjaldur)</translation>
    </message>
</context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Settings file %1 might be corrupt or invalid.</source>
        <translation type="unfinished">Uppsetanarfílan %1 kann vera avskeplað ella ógildig.</translation>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">Innanhýsis villa</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Do you want to reset settings to default values, or to abort without making changes?</source>
        <extracomment>Explanatory text shown on startup when the settings file cannot be read. Prompts user to make a choice between resetting or aborting.</extracomment>
        <translation type="unfinished">Ynskir tú at endurstilla stillingar til upprunaligar stillingar, ella at avlýsa broytingar?</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">Villa: %1</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Upphædd</translation>
    </message>
    <message>
        <source>Enter a Bitcoin address (e.g. %1)</source>
        <translation type="unfinished">Inntøppa eina Bitcoin adressu (t.d. %1)</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation type="unfinished">CTRL+W</translation>
    </message>
    <message>
        <source>Inbound</source>
        <extracomment>An inbound connection from a peer. An inbound connection is a connection initiated by a peer.</extracomment>
        <translation type="unfinished">Inngangandi</translation>
    </message>
    <message>
        <source>Outbound</source>
        <extracomment>An outbound connection to a peer. An outbound connection is a connection initiated by us.</extracomment>
        <translation type="unfinished">Útgangandi</translation>
    </message>
    <message>
        <source>%1 h</source>
        <translation type="unfinished">%1 t</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform>%n sekund</numerusform>
            <numerusform>%n sekund</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform>%n minuttur</numerusform>
            <numerusform>%n minuttir</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform>%n tími</numerusform>
            <numerusform>%n tímar</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform>%n dagur</numerusform>
            <numerusform>%n dagar</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform>%n vika</numerusform>
            <numerusform>%n vikur</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation type="unfinished">%1 og %2</translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform>%n ár</numerusform>
            <numerusform>%n ár</numerusform>
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation type="unfinished">&amp;Yvirlit</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="unfinished">Sløkk forrit</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation type="unfinished">&amp;Um %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation type="unfinished">Vís upplýsingar um %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished">Um &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation type="unfinished">Vís upplýsingar um Qt</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation type="unfinished">Broyt uppsetanarstillingar fyri %1</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">Net-virksemi óvirkijað.</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation type="unfinished">&amp;Móttak</translation>
    </message>
    <message>
        <source>Sign &amp;message…</source>
        <translation type="unfinished">&amp;Undirrita  boð</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation type="unfinished">Undirrita boðini við tíni Bitcoin-adressu fyri at prógva at tey eru tíni</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Fíla</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Stillingar</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Hjálp</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation type="unfinished">%1 aftanfyri</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Villa</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Ávaring</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation type="unfinished">Javnsettur</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation type="unfinished">CTRL+Q</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation type="unfinished">CTRL+M</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation type="unfinished">%1 viðskiftari</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform>%n virkið samband til Bitcoin netið.</numerusform>
            <numerusform>%n virkin sambond til Bitcoin netið.</numerusform>
        </translation>
    </message>
    <message>
        <source>Disable network activity</source>
        <extracomment>A context menu item.</extracomment>
        <translation type="unfinished">Óvirkja net-virksemið.</translation>
    </message>
    <message>
        <source>Enable network activity</source>
        <extracomment>A context menu item. The network activity was disabled previously.</extracomment>
        <translation type="unfinished">Virkja net-virksemið.</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">Villa: %1</translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation type="unfinished">Ávaring: %1</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation type="unfinished">Spjaldur: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation type="unfinished">Adressa: %1
</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">Mongd:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Byte:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Upphædd:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">Vekslipeningur:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation type="unfinished">(frá)vel alt</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Upphædd</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Avrita mongd</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Avrita adressu</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">Avrita &amp;spjaldur</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">Avrita &amp;upphædd</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">Avrita mongd</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation type="unfinished">Avrita být</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">Avrita vekslipening</translation>
    </message>
    <message>
        <source>Can vary +/- %1 satoshi(s) per input.</source>
        <translation type="unfinished">Kann vera ymiskt +/- %1 satoshi fyri hvørt ískoyti.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(einki spjaldur)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation type="unfinished">vekslipeningur frá %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation type="unfinished">(vekslipeningur)</translation>
    </message>
</context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Advanced Options</source>
        <translation type="unfinished">Víðkaðar stillingar</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation type="unfinished">Broyt adressu</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation type="unfinished">&amp;Spjaldur</translation>
    </message>
    <message>
        <source>The label associated with this address list entry</source>
        <translation type="unfinished">Spjaldrið knýtt at hesi adressuni í adressuskránni</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">&amp;Adressa</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>name</source>
        <translation type="unfinished">navn</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform>%n GB av goymsluplássi tøkt</numerusform>
            <numerusform>%n GB av goymsluplássi tøkt</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform>(av %n GB ið tørvur er á)</numerusform>
            <numerusform>(av %n GB ið tørvur er á)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Approximately %1 GB of data will be stored in this directory.</source>
        <translation type="unfinished">Á leið %1 GB av dátum verða goymd í hesi fíluskránni.</translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Villa</translation>
    </message>
    <message>
        <source>Welcome</source>
        <translation type="unfinished">Vælkomin</translation>
    </message>
    <message>
        <source>Welcome to %1.</source>
        <translation type="unfinished">Vælkomin til %1.</translation>
    </message>
    <message>
        <source> GB</source>
        <translation type="unfinished">GB</translation>
    </message>
    <message>
        <source>This initial synchronisation is very demanding, and may expose hardware problems with your computer that had previously gone unnoticed. Each time you run %1, it will continue downloading where it left off.</source>
        <translation type="unfinished">Hendan innleiðandi stevjavningin er sera krevjandi, og kann avdúka trupulleikar, við tólbúnaðinum í teldu tíni, ið tú annars ikki hevur varnast. %1 heldur á fram at takað niður, hvørja ferð %1 verður koyrt.</translation>
    </message>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>About %1</source>
        <translation type="unfinished">Um %1</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    <message>
        <source>%1 is shutting down…</source>
        <translation type="unfinished">%1 letur aftur...</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Progress</source>
        <translation type="unfinished">Gongd</translation>
    </message>
    <message>
        <source>Progress increase per hour</source>
        <translation type="unfinished">Framgongd um tíman</translation>
    </message>
    <message>
        <source>Estimated time left until synced</source>
        <translation type="unfinished">Mett tíð eftir til fulla stevjavnan</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished">Loka</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation type="unfinished">Stillingar</translation>
    </message>
    <message>
        <source>Automatically start %1 after logging in to the system.</source>
        <translation type="unfinished">Koyr %1 sjálvvirkandi eftir innritan á stýrikervið</translation>
    </message>
    <message>
        <source>Full path to a %1 compatible script (e.g. C:\Downloads\hwi.exe or /Users/you/Downloads/hwi.py). Beware: malware can steal your coins!</source>
        <translation type="unfinished">Fullfíggja leið til eitt %1 sambæriligt skeljarrit (t.d. C:\Downloads\hwi.exe ella /Users/you/Downloads/hwi.py). Gev gætur: Illbúnaður kann stjala tín pening!</translation>
    </message>
    <message>
        <source>Open Configuration File</source>
        <translation type="unfinished">Lat upp uppsetanarfíl</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation type="unfinished">Endurstilla allar viðskiftarastillingar til sjálvsettar.</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation type="unfinished">&amp;Endurstilla stillingar</translation>
    </message>
    <message>
        <source>Automatically open the Bitcoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation type="unfinished">Sjálvvirkandi upplating av Bicoin viðskiftara porturinum á beinaranum. Hetta virkar bert um UPnP er virkja í beinaranum, á netinum tú brúkar.</translation>
    </message>
    <message>
        <source>Automatically open the Bitcoin client port on the router. This only works when your router supports NAT-PMP and it is enabled. The external port could be random.</source>
        <translation type="unfinished">Sjálvvirkandi upplating av Bicoin viðskiftara porturinum á beinaranum. Hetta virkar bert um NAT-PMP er virkja í beinaranum, á netinum tú brúkar. Ytra porturnummari kann vera tilvildarligt.</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation type="unfinished">&amp;Portur:</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation type="unfinished">Mál á nýtaramóti:</translation>
    </message>
    <message>
        <source>The user interface language can be set here. This setting will take effect after restarting %1.</source>
        <translation type="unfinished">Her kann mál á nýtaramóti ásetast. Stillingin hevur virknað eftir at %1 er endurbyrja.</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Avlýs</translation>
    </message>
    <message>
        <source>default</source>
        <translation type="unfinished">sjálvsett</translation>
    </message>
    <message>
        <source>Confirm options reset</source>
        <extracomment>Window title text of pop-up window shown when the user has chosen to reset options.</extracomment>
        <translation type="unfinished">Vátta endurstilling av stillingum</translation>
    </message>
    <message>
        <source>Client restart required to activate changes.</source>
        <extracomment>Text explaining that the settings changed will not come into effect until the client is restarted.</extracomment>
        <translation type="unfinished">Endurbyrjan av viðskiftara kravd fyri at virkja broyting(ar).</translation>
    </message>
    <message>
        <source>Client will be shut down. Do you want to proceed?</source>
        <extracomment>Text asking the user to confirm if they would like to proceed with a client shutdown.</extracomment>
        <translation type="unfinished">Viðskiftari verður slóktur. Ynskir tú at halda áfram?</translation>
    </message>
    <message>
        <source>Configuration options</source>
        <extracomment>Window title text of pop-up box that allows opening up of configuration file.</extracomment>
        <translation type="unfinished">Uppsetanarstillingar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Avlýs</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Villa</translation>
    </message>
    <message>
        <source>The configuration file could not be opened.</source>
        <translation type="unfinished">Innlesan av uppsetanarfílu miseydnaðist.</translation>
    </message>
    <message>
        <source>This change would require a client restart.</source>
        <translation type="unfinished">Broytingin krevur endurbyrjan av viðskiftaranum.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Available:</source>
        <translation type="unfinished">Tókt:</translation>
    </message>
    <message>
        <source>Pending:</source>
        <translation type="unfinished">Óváttað:</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Save…</source>
        <translation type="unfinished">Goym...</translation>
    </message>
    <message>
        <source>own address</source>
        <translation type="unfinished">egin adressa</translation>
    </message>
    <message>
        <source>Total Amount</source>
        <translation type="unfinished">Samlað upphædd</translation>
    </message>
    <message>
        <source>or</source>
        <translation type="unfinished">ella</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Age</source>
        <extracomment>Title of Peers Table column which indicates the duration (length of time) since the peer connection started.</extracomment>
        <translation type="unfinished">Aldur</translation>
    </message>
    <message>
        <source>Received</source>
        <extracomment>Title of Peers Table column which indicates the total amount of network information we have received from the peer.</extracomment>
        <translation type="unfinished">Móttikið</translation>
    </message>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">Adressa</translation>
    </message>
    <message>
        <source>Type</source>
        <extracomment>Title of Peers Table column which describes the type of peer connection. The "type" describes why the connection exists.</extracomment>
        <translation type="unfinished">Slag</translation>
    </message>
    <message>
        <source>Network</source>
        <extracomment>Title of Peers Table column which states the network the peer connected through.</extracomment>
        <translation type="unfinished">Net</translation>
    </message>
    <message>
        <source>Inbound</source>
        <extracomment>An Inbound Connection from a Peer.</extracomment>
        <translation type="unfinished">Inngangandi</translation>
    </message>
    <message>
        <source>Outbound</source>
        <extracomment>An Outbound Connection to a Peer.</extracomment>
        <translation type="unfinished">Útgangandi</translation>
    </message>
</context>
<context>
    <name>QRImageWidget</name>
    <message>
        <source>&amp;Save Image…</source>
        <translation type="unfinished">&amp;Goym mynd...</translation>
    </message>
    <message>
        <source>&amp;Copy Image</source>
        <translation type="unfinished">&amp;Avrita mynd</translation>
    </message>
    <message>
        <source>Save QR Code</source>
        <translation type="unfinished">Goym QR kotu</translation>
    </message>
    <message>
        <source>PNG Image</source>
        <extracomment>Expanded name of the PNG file format. See: https://en.wikipedia.org/wiki/Portable_Network_Graphics.</extracomment>
        <translation type="unfinished">PNG mynd</translation>
    </message>
</context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Client version</source>
        <translation type="unfinished">Viðskiftaraútgáva</translation>
    </message>
    <message>
        <source>Network</source>
        <translation type="unfinished">Net</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished">Navn</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation type="unfinished">Tal av sambondum</translation>
    </message>
    <message>
        <source>Memory usage</source>
        <translation type="unfinished">Minnisnýtsla</translation>
    </message>
    <message>
        <source>&amp;Reset</source>
        <translation type="unfinished">Tómstilla</translation>
    </message>
    <message>
        <source>Received</source>
        <translation type="unfinished">Móttikið</translation>
    </message>
    <message>
        <source>Version</source>
        <translation type="unfinished">Útgáva</translation>
    </message>
    <message>
        <source>Ping Time</source>
        <translation type="unfinished">Ping tíð</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation type="unfinished">Gerðalistafíla til villukemban</translation>
    </message>
    <message>
        <source>In:</source>
        <translation type="unfinished">Niður:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation type="unfinished">Upp:</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <extracomment>Main shortcut to increase the RPC console font size.</extracomment>
        <translation type="unfinished">CTRL++</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <extracomment>Secondary shortcut to increase the RPC console font size.</extracomment>
        <translation type="unfinished">CTRL+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <extracomment>Main shortcut to decrease the RPC console font size.</extracomment>
        <translation type="unfinished">CTRL+-</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <extracomment>Secondary shortcut to decrease the RPC console font size.</extracomment>
        <translation type="unfinished">CTRL+_</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer.</extracomment>
        <translation type="unfinished">&amp;Avrita adressu</translation>
    </message>
    <message>
        <source>1 &amp;hour</source>
        <translation type="unfinished">1 &amp;tíma</translation>
    </message>
    <message>
        <source>1 d&amp;ay</source>
        <translation type="unfinished">1 &amp;dag</translation>
    </message>
    <message>
        <source>1 &amp;week</source>
        <translation type="unfinished">1 &amp;viku</translation>
    </message>
    <message>
        <source>1 &amp;year</source>
        <translation type="unfinished">1 &amp;ár</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation type="unfinished">CTRL+I</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation type="unfinished">CTRL+T</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation type="unfinished">CTRL+N</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation type="unfinished">CTRL+P</translation>
    </message>
    <message>
        <source>Executing…</source>
        <extracomment>A console message indicating an entered command is currently being executed.</extracomment>
        <translation type="unfinished">Innir...</translation>
    </message>
    <message>
        <source>via %1</source>
        <translation type="unfinished">umvegis %1</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished">Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished">Nei</translation>
    </message>
    <message>
        <source>To</source>
        <translation type="unfinished">Til</translation>
    </message>
    <message>
        <source>From</source>
        <translation type="unfinished">Frá</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;Spjaldur:</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished">Tómstilla</translation>
    </message>
    <message>
        <source>Show</source>
        <translation type="unfinished">Vís</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Avrita adressu</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">Avrita &amp;spjaldur</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">Avrita &amp;upphædd</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address:</source>
        <translation type="unfinished">Adressu:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Upphædd:</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation type="unfinished">Spjaldur:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation type="unfinished">Boð:</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation type="unfinished">Avrita &amp;adressu</translation>
    </message>
    <message>
        <source>&amp;Save Image…</source>
        <translation type="unfinished">&amp;Goym mynd...</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Spjaldur</translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished">Boð</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(einki spjaldur)</translation>
    </message>
    <message>
        <source>(no message)</source>
        <translation type="unfinished">(eingi boð)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">Mongd:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Byte:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Upphædd:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">Vekslipeningur:</translation>
    </message>
    <message>
        <source>If this is activated, but the change address is empty or invalid, change will be sent to a newly generated address.</source>
        <translation type="unfinished">Um hetta er virkja, men teigurin til adressu fyri vekslipening er tómur ella ógildigur, so verður vekslipeningurin sendur til eina ný-myndaða adressu.</translation>
    </message>
    <message>
        <source>Custom change address</source>
        <translation type="unfinished">Adressa til vekslipening</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished">Loka</translation>
    </message>
    <message>
        <source>Recommended:</source>
        <translation type="unfinished">Viðmælt:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation type="unfinished">Send til fleiri móttakarar í einum</translation>
    </message>
    <message>
        <source>Choose…</source>
        <translation type="unfinished">Vel...</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation type="unfinished">Tómstilla &amp;alt</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">Avrita mongd</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Avrita mongd</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation type="unfinished">Avrita být</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">Avrita vekslipening</translation>
    </message>
    <message>
        <source>Sign on device</source>
        <extracomment>"device" usually means a hardware wallet.</extracomment>
        <translation type="unfinished">Undirrita á eind</translation>
    </message>
    <message>
        <source>%1 to '%2'</source>
        <translation type="unfinished">%1 til '%2'</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="unfinished">%1 til %2</translation>
    </message>
    <message>
        <source>Sign failed</source>
        <translation type="unfinished">Undirritan miseydnaðist</translation>
    </message>
    <message>
        <source>or</source>
        <translation type="unfinished">ella</translation>
    </message>
    <message>
        <source>Total Amount</source>
        <translation type="unfinished">Samlað upphædd</translation>
    </message>
    <message>
        <source>The recipient address is not valid. Please recheck.</source>
        <translation type="unfinished">Móttakara adressan er ógildig. Vinaliga eftirkanna.</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Warning: Invalid Bitcoin address</source>
        <translation type="unfinished">Ávaring: Ógildig Bitcoin adressa</translation>
    </message>
    <message>
        <source>Warning: Unknown change address</source>
        <translation type="unfinished">Ávaring: Ókend adressa til vekslipening</translation>
    </message>
    <message>
        <source>Confirm custom change address</source>
        <translation type="unfinished">Váttað adressu til vekslipening</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(einki spjaldur)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;Spjaldur:</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation type="unfinished">Brúka adressuna ið frammanundan var brúkt</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation type="unfinished">ALT+A</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation type="unfinished">ALT+P</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation type="unfinished">Boð:</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation type="unfinished">Undirskriftir - Undirrita / Vátta eini boð</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation type="unfinished">&amp;Undirrita Boð</translation>
    </message>
    <message>
        <source>You can sign messages/agreements with your addresses to prove you can receive bitcoins sent to them. Be careful not to sign anything vague or random, as phishing attacks may try to trick you into signing your identity over to them. Only sign fully-detailed statements you agree to.</source>
        <translation type="unfinished">Tú kann skriva undir boð/sáttmálar við tínum adressum, fyri at prógva at tú kanst móttaka bitcoin sendar til tær. Ver ansin so tú ikki skrivar undir nakað ógreitt ella tilvildarligt, tí fysking-álop kunnu royna at snýta teg til at latað tín samleika til tey. Undirrita einans nágreiniligar útsagnir ið tú tekur undir við.</translation>
    </message>
    <message>
        <source>The Bitcoin address to sign the message with</source>
        <translation type="unfinished">Bitcoin adressan at undirskriva boðini við</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation type="unfinished">Brúka adressuna ið frammanundan var brúkt</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation type="unfinished">ALT+A</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation type="unfinished">ALT+P</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation type="unfinished">Inntøppa boðini, tú ynskir at undirrita, her</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation type="unfinished">Undirskrift</translation>
    </message>
    <message>
        <source>Sign the message to prove you own this Bitcoin address</source>
        <translation type="unfinished">Undirskriva boðini fyri at prógva at Bitcoin-adressan er tín</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation type="unfinished">&amp;Undirrita boð</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation type="unfinished">Tómstilla &amp;alt</translation>
    </message>
    <message>
        <source>The Bitcoin address the message was signed with</source>
        <translation type="unfinished">Bitcoin-adressan ið undirskrivaði boðini</translation>
    </message>
    <message>
        <source>The signed message to verify</source>
        <translation type="unfinished">Undirritað boð at vátta</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation type="unfinished">Trýst á "Undirrita boð" fyri at gera eina undirskrift</translation>
    </message>
    <message>
        <source>No error</source>
        <translation type="unfinished">Eingin villa</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation type="unfinished">Undirritan av boðum miseydnaðist.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation type="unfinished">Boð undirritað</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation type="unfinished">Undirskriftin er ógildig.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation type="unfinished">Vinaliga kanna undirskriftina og royn aftur.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation type="unfinished">Undirskriftin samsvaraði ikki við innihaldi í boðnum.</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Source</source>
        <translation type="unfinished">Kelda</translation>
    </message>
    <message>
        <source>From</source>
        <translation type="unfinished">Frá</translation>
    </message>
    <message>
        <source>To</source>
        <translation type="unfinished">Til</translation>
    </message>
    <message>
        <source>own address</source>
        <translation type="unfinished">egin adressa</translation>
    </message>
    <message>
        <source>label</source>
        <translation type="unfinished">spjaldur</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished">Boð</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation type="unfinished">Viðmerking</translation>
    </message>
    <message>
        <source>Inputs</source>
        <translation type="unfinished">Ískoytir</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Upphædd</translation>
    </message>
    <message>
        <source>true</source>
        <translation type="unfinished">satt</translation>
    </message>
    <message>
        <source>false</source>
        <translation type="unfinished">ósatt</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Details for %1</source>
        <translation type="unfinished">Nágreinilig lýsing um %1</translation>
    </message>
</context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Type</source>
        <translation type="unfinished">Slag</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Spjaldur</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation type="unfinished">Sent til</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(einki spjaldur)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation type="unfinished">Í dag</translation>
    </message>
    <message>
        <source>This week</source>
        <translation type="unfinished">Hesa vikuna</translation>
    </message>
    <message>
        <source>This month</source>
        <translation type="unfinished">Hendan mánaðin</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation type="unfinished">Síðsta mánað</translation>
    </message>
    <message>
        <source>This year</source>
        <translation type="unfinished">Í ár</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation type="unfinished">Sent til</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation type="unfinished">Minstaupphædd</translation>
    </message>
    <message>
        <source>Range…</source>
        <translation type="unfinished">Talstrekki...</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Avrita adressu</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">Avrita &amp;spjaldur</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">Avrita &amp;upphædd</translation>
    </message>
    <message>
        <source>&amp;Edit address label</source>
        <translation type="unfinished">&amp;Broyt adressuspjaldur</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <extracomment>Transactions table context menu action to show the selected transaction in a third-party block explorer. %1 is a stand-in argument for the URL of the explorer.</extracomment>
        <translation type="unfinished">Vís í %1</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Slag</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Spjaldur</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Adressa</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation type="unfinished">Talstrekki:</translation>
    </message>
    <message>
        <source>to</source>
        <translation type="unfinished">til</translation>
    </message>
</context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Error</source>
        <translation type="unfinished">Villa</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Increase:</source>
        <translation type="unfinished">Øking:</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Avlýs</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>The %s developers</source>
        <translation type="unfinished">%smennararnir</translation>
    </message>
    <message>
        <source>%s request to listen on port %u. This port is considered "bad" and thus it is unlikely that any peer will connect to it. See doc/p2p-bad-ports.md for details and a full list.</source>
        <translation type="unfinished">%s umbøn at lurta á portur %u. Hetta portrið er tulkað "óhóskandi" og tí er ósannlíkt at nakar viðskiftari sambindur í tað. Sí lista yvir "óhóskandi" portur og nágreiniligari upplýsingar í doc/p2p-bad-ports.md.</translation>
    </message>
    <message>
        <source>Please check that your computer's date and time are correct! If your clock is wrong, %s will not work properly.</source>
        <translation type="unfinished">Vinaliga tryggja at dagfesting og tíð, í teldu tíni, eru røtt! Er klokkan skeiv virkar %s ikki sum ætlað.</translation>
    </message>
    <message>
        <source>%s is set very high!</source>
        <translation type="unfinished">Ásetingin %s er sera høgt!</translation>
    </message>
    <message>
        <source>-maxmempool must be at least %d MB</source>
        <translation type="unfinished">-maxmempool skal vera í minsta lagi %d MB</translation>
    </message>
    <message>
        <source>Outbound connections restricted to CJDNS (-onlynet=cjdns) but -cjdnsreachable is not provided</source>
        <translation type="unfinished">Útgangandi sambond eru avmarkaði til CJDNS (-onlynet=cjdns) men -cjdnsreachable er ikki ásett.</translation>
    </message>
    <message>
        <source>Outbound connections restricted to i2p (-onlynet=i2p) but -i2psam is not provided</source>
        <translation type="unfinished">Útgangandi sambond avmarkaði til i2p (-onlynet=i2p) men -i2psam er ikki ásett.</translation>
    </message>
    <message>
        <source>Error loading %s</source>
        <translation type="unfinished">Villa við innlesan %s</translation>
    </message>
    <message>
        <source>Error reading configuration file: %s</source>
        <translation type="unfinished">Villa við innlesing av uppsetanarfílu: %s</translation>
    </message>
    <message>
        <source>Error reading from database, shutting down.</source>
        <translation type="unfinished">Villa við innlesan av dátugrunni. Letur aftur.</translation>
    </message>
    <message>
        <source>Error: Disk space is low for %s</source>
        <translation type="unfinished">Villa: Tøkt disk goymslupláss og lítið til %s</translation>
    </message>
    <message>
        <source>Error: Got key that was not hex: %s</source>
        <translation type="unfinished">Villa: Fekk lykil ið ikki er sekstandatal: %s</translation>
    </message>
    <message>
        <source>Error: Got value that was not hex: %s</source>
        <translation type="unfinished">Villa: Fekk virði ið ikki er sekstandatal: %s</translation>
    </message>
    <message>
        <source>Error: No %s addresses available.</source>
        <translation type="unfinished">Villa: Ongar %s adressur tøkar.</translation>
    </message>
    <message>
        <source>Error: Unable to begin reading all records in the database</source>
        <translation type="unfinished">Villa: Bar ikki til at byrja at innlesa skrásetingar í dátugrunninum</translation>
    </message>
    <message>
        <source>Error: Unable to parse version %u as a uint32_t</source>
        <translation type="unfinished">Villa: Bar ikki til at tulkað útgávu %u sum uint32_t</translation>
    </message>
    <message>
        <source>Error: Unable to read all records in the database</source>
        <translation type="unfinished">Villa: Bar ikki til at innlesa allar skrásetingar í dátugrunninum</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation type="unfinished">Miseydnaðist at lurta á nøkrum portri. Brúka -listen=0 um tú ikki ynskir at lurta á nøkrum portri.</translation>
    </message>
    <message>
        <source>Listening for incoming connections failed (listen returned error %s)</source>
        <translation type="unfinished">Lurtingin eftir inngangandi sambondum miseydnaðist (lurtingin gav villuna %s)</translation>
    </message>
    <message>
        <source>No addresses available</source>
        <translation type="unfinished">Ongar adressur tøkar</translation>
    </message>
    <message>
        <source>The source code is available from %s.</source>
        <translation type="unfinished">Keldukotan er tøk á %s.</translation>
    </message>
    <message>
        <source>The specified config file %s does not exist</source>
        <translation type="unfinished">Ásetta uppsetanarfílan %s finst ikki</translation>
    </message>
    <message>
        <source>This is experimental software.</source>
        <translation type="unfinished">Hetta er royndar-ritbúnaður.</translation>
    </message>
    <message>
        <source>Settings file could not be read</source>
        <translation type="unfinished">Lesing av uppsetanarfílu miseydnaðist</translation>
    </message>
    <message>
        <source>Settings file could not be written</source>
        <translation type="unfinished">Skriving av uppsetanarfílu miseydnaðist</translation>
    </message>
</context>
</TS>